@@ -110,7 +110,7 @@ class IRM:
         else:
             hrf = ifft(self.hrf_fft, axis = 0)[0:self.l_hrf]
 
-        return np.abs(hrf)
+        return np.real(hrf)
 
     def get_stimulus(self):
         '''
@@ -130,7 +130,7 @@ class IRM:
             predicted timecourses
         '''
 
-        return np.abs(ifft(self.tc_fft, axis = 0)[0:self.n_samples, :])
+        return np.real(ifft(self.tc_fft, axis = 0)[0:self.n_samples, :])
 
     def set_hrf(self, hrf):
         '''
@@ -256,7 +256,7 @@ class IRM:
         if self.hrf_fft.ndim==1:
             tc = np.transpose(
                 zscore(
-                    np.abs(
+                    np.real(
                         ifft(self.tc_fft *
                              np.expand_dims(self.hrf_fft,
                                             axis = 1), axis = 0)), axis = 0))
@@ -287,7 +287,7 @@ class IRM:
 
                 tc = np.transpose(
                     zscore(
-                        np.abs(
+                        np.real(
                             ifft(self.tc_fft *
                                  np.expand_dims(self.hrf_fft[:, v],
                                                 axis = 1), axis = 0)), axis = 0))
