@@ -116,7 +116,7 @@ class pRF:
         else:
             hrf = ifft(self.hrf_fft, axis=0)[0:self.l_hrf]
 
-        return np.abs(hrf)
+        return np.real(hrf)
 
     def get_stimulus(self):
         '''
@@ -141,7 +141,7 @@ class pRF:
             predicted timecourses
         '''
 
-        return np.abs(ifft(self.tc_fft, axis=0)[0:self.n_samples, :])
+        return np.real(ifft(self.tc_fft, axis=0)[0:self.n_samples, :])
 
     def set_hrf(self, hrf):
         '''
@@ -287,7 +287,7 @@ class pRF:
             predicted timecourses
         '''
 
-        return np.abs(ifft(self.tc_fft, axis=0)[0:self.n_samples, :])
+        return np.real(ifft(self.tc_fft, axis=0)[0:self.n_samples, :])
 
     def set_hrf(self, hrf):
         '''
@@ -482,21 +482,15 @@ class pRF:
 
      print('\nmapping receptive fields')
 
-     data = np.reshape(data.astype(float),
-                       (self.n_samples,
-                        self.n_total))
-
      mean_signal = np.mean(data, axis = 0)
      sdev_signal = np.std(data, axis = 0)
 
-
      if np.size(mask) == 0:
          mask = mean_signal >= threshold
 
-     mask = np.reshape(mask, self.n_total)
      mask = mask.astype(bool) & (sdev_signal > 0)
-
      data = zscore(data[:, mask], axis=0)
+     mask = mask.flatten()
 
      voxel_index = np.where(mask)[0]
      n_voxels = voxel_index.size
@@ -511,7 +505,7 @@ class pRF:
      if self.hrf_fft.ndim == 1:
          tc = np.transpose(
              zscore(
-                 np.abs(
+                 np.real(
                      ifft(self.tc_fft *
                           np.expand_dims(self.hrf_fft,
                                          axis=1), axis=0)), axis=0))
@@ -545,7 +539,7 @@ class pRF:
 
              tc = np.transpose(
                  zscore(
-                     np.abs(
+                     np.real(
                          ifft(self.tc_fft *
                               np.expand_dims(self.hrf_fft[:, v],
                                              axis=1), axis=0)), axis=0))
@@ -591,21 +585,15 @@ class pRF:
 
      print('\nmapping receptive fields')
 
-     data = np.reshape(data.astype(float),
-                       (self.n_samples,
-                        self.n_total))
-
      mean_signal = np.mean(data, axis = 0)
      sdev_signal = np.std(data, axis = 0)
 
-
      if np.size(mask) == 0:
          mask = mean_signal >= threshold
 
-     mask = np.reshape(mask, self.n_total)
      mask = mask.astype(bool) & (sdev_signal > 0)
-
      data = zscore(data[:, mask], axis=0)
+     mask = mask.flatten()
 
      voxel_index = np.where(mask)[0]
      n_voxels = voxel_index.size
@@ -620,7 +608,7 @@ class pRF:
      if self.hrf_fft.ndim == 1:
          tc = np.transpose(
              zscore(
-                 np.abs(
+                 np.real(
                      ifft(self.tc_fft *
                           np.expand_dims(self.hrf_fft,
                                          axis=1), axis=0)), axis=0))
@@ -653,7 +641,7 @@ class pRF:
 
              tc = np.transpose(
                  zscore(
-                     np.abs(
+                     np.real(
                          ifft(self.tc_fft *
                               np.expand_dims(self.hrf_fft[:, v],
                                              axis=1), axis=0)), axis=0))
